@@ -10,9 +10,9 @@ from __future__ import absolute_import
 
 from .caching import *
 
-
-from numpy.testing import Tester
-test = Tester().test
+from numpy._pytesttester import PytestTester
+test = PytestTester(__name__)
+del PytestTester
 
 
 
