@@ -7,9 +7,9 @@ imported from this module
 from __future__ import absolute_import
 
 
-
-from numpy.testing import Tester
-test = Tester().test
+from numpy._pytesttester import PytestTester
+test = PytestTester(__name__)
+del PytestTester
 
 
 from .parallel_api import distribute
