@@ -14,6 +14,16 @@ import numpy as num
 import os
 import subprocess
 
+# Setup to skip test if mpi4py not available
+import sys
+try:
+    import mpi4py
+except ImportError:
+    pass
+
+import pytest
+
+
 verbose = False
 
 path = os.path.dirname(__file__)  # Get folder where this script lives
@@ -23,6 +33,8 @@ run_filename = os.path.join(path, 'run_parallel_distribute_domain.py')
 sequential_file = 'distribute_domain_sequential.txt'
 parallel_file = 'distribute_domain_parallel.txt'
 
+@pytest.mark.skipif('mpi4py' not in sys.modules,
+                    reason="requires the mpi4py module")
 class Test_parallel_distribute_domain(unittest.TestCase):
     def setUp(self):
         # Run the sequential and parallel simulations to produce sww files for comparison.
