@@ -14,6 +14,15 @@ import numpy as num
 import os
 import subprocess
 
+# Setup to skip test if mpi4py not available
+import sys
+try:
+    import mpi4py
+except ImportError:
+    pass
+
+import pytest
+
 verbose = False
 
 path = os.path.dirname(__file__)  # Get folder where this script lives
@@ -23,6 +32,8 @@ run_filename = os.path.join(path, 'run_parallel_shallow_domain.py')
 sequential_sww_file = 'shallow_water_sequential.sww'
 parallel_sww_file = 'shallow_water_parallel.sww'
 
+@pytest.mark.skipif('mpi4py' not in sys.modules,
+                    reason="requires the mpi4py module")
 class Test_parallel_shallow_domain(unittest.TestCase):
     def setUp(self):
         # Run the sequential and parallel simulations to produce sww files for comparison.
