@@ -5,5 +5,6 @@
 
 """
 
-from numpy.testing import Tester
-test = Tester().test
+from numpy._pytesttester import PytestTester
+test = PytestTester(__name__)
+del PytestTester
\ No newline at end of file
