@@ -5,8 +5,10 @@
     extra boundary classes to do with this specific domain.
 """
 
-from numpy.testing import Tester
-test = Tester().test
+from numpy._pytesttester import PytestTester
+test = PytestTester(__name__)
+del PytestTester
+
 
 
 
