@@ -3,8 +3,9 @@
 """
 from __future__ import absolute_import
 
-from numpy.testing import Tester
-test = Tester().test
+from numpy._pytesttester import PytestTester
+test = PytestTester(__name__)
+del PytestTester
 
 
 from .typeset_report import typeset_report
